@@ -2,7 +2,30 @@
 
 from __future__ import division
 
-__version__ = "2.0.1"
+__version__ = "2.0.2"
+
+
+def _optional_int(value):
+    """Converts a ``float`` to an ``int`` if they're the same value
+
+    Args:
+        value (float)
+
+    Returns:
+        Either the original input or the input as an ``int``
+
+    Example:
+        >>> _optional_int(3.0)
+        3
+
+        >>> _optional_int(1.2)
+        1.2
+    """
+
+    if value == int(value):
+        return int(value)
+
+    return value
 
 
 def average(values):
@@ -21,10 +44,7 @@ def average(values):
 
     res = sum(values) / len(values)
 
-    if res == int(res):
-        return int(res)
-
-    return res
+    return _optional_int(res)
 
 
 def weighted_average(values):
@@ -42,18 +62,15 @@ def weighted_average(values):
         1.6
     """
 
-    if any(weight < 0 for _, weight in values):
-        raise ValueError("Weights cannot be less than zero")
-
     dividend, divisor = 0, 0
 
     for value, weight in values:
+        if weight < 0:
+            raise ValueError("Weights cannot be less than zero")
+
         dividend += value * weight
         divisor += weight
 
     res = dividend / divisor
 
-    if res == int(res):
-        return int(res)
-
-    return res
+    return _optional_int(res)
